============
Installation
============

At the command line::

    $ pip install reno

.. note::

   Reno's dependencies include C extension modules, which in turn
   depend on having the Python source header files installed.

Sphinx Extension
================

To use the Sphinx extension built into reno, install the ``[sphinx]``
extra dependencies::

    $ pip install 'reno[sphinx]'
